# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class GenerativefirewallIndividualRulesConfig(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'data_leakage': 'GenerativefirewallDataLeakageRuleConfig',
        'off_topic': 'GenerativefirewallOffTopicRuleConfig',
        'denial_of_service': 'GenerativefirewallDenialOfServiceRuleConfig',
        'consistency_with_knowledgebase': 'GenerativefirewallConsistencyWithKnowledgebaseRuleConfig',
        'indirect_prompt_injection': 'GenerativefirewallIndirectPromptInjectionRuleConfig',
        'pii_detection_input': 'GenerativefirewallPiiDetectionRuleConfig',
        'pii_detection_output': 'GenerativefirewallPiiDetectionRuleConfig'
    }

    attribute_map = {
        'data_leakage': 'dataLeakage',
        'off_topic': 'offTopic',
        'denial_of_service': 'denialOfService',
        'consistency_with_knowledgebase': 'consistencyWithKnowledgebase',
        'indirect_prompt_injection': 'indirectPromptInjection',
        'pii_detection_input': 'piiDetectionInput',
        'pii_detection_output': 'piiDetectionOutput'
    }

    def __init__(self, data_leakage=None, off_topic=None, denial_of_service=None, consistency_with_knowledgebase=None, indirect_prompt_injection=None, pii_detection_input=None, pii_detection_output=None):  # noqa: E501
        """GenerativefirewallIndividualRulesConfig - a model defined in Swagger"""  # noqa: E501
        self._data_leakage = None
        self._off_topic = None
        self._denial_of_service = None
        self._consistency_with_knowledgebase = None
        self._indirect_prompt_injection = None
        self._pii_detection_input = None
        self._pii_detection_output = None
        self.discriminator = None
        if data_leakage is not None:
            self.data_leakage = data_leakage
        if off_topic is not None:
            self.off_topic = off_topic
        if denial_of_service is not None:
            self.denial_of_service = denial_of_service
        if consistency_with_knowledgebase is not None:
            self.consistency_with_knowledgebase = consistency_with_knowledgebase
        if indirect_prompt_injection is not None:
            self.indirect_prompt_injection = indirect_prompt_injection
        if pii_detection_input is not None:
            self.pii_detection_input = pii_detection_input
        if pii_detection_output is not None:
            self.pii_detection_output = pii_detection_output

    @property
    def data_leakage(self):
        """Gets the data_leakage of this GenerativefirewallIndividualRulesConfig.  # noqa: E501


        :return: The data_leakage of this GenerativefirewallIndividualRulesConfig.  # noqa: E501
        :rtype: GenerativefirewallDataLeakageRuleConfig
        """
        return self._data_leakage

    @data_leakage.setter
    def data_leakage(self, data_leakage):
        """Sets the data_leakage of this GenerativefirewallIndividualRulesConfig.


        :param data_leakage: The data_leakage of this GenerativefirewallIndividualRulesConfig.  # noqa: E501
        :type: GenerativefirewallDataLeakageRuleConfig
        """

        self._data_leakage = data_leakage

    @property
    def off_topic(self):
        """Gets the off_topic of this GenerativefirewallIndividualRulesConfig.  # noqa: E501


        :return: The off_topic of this GenerativefirewallIndividualRulesConfig.  # noqa: E501
        :rtype: GenerativefirewallOffTopicRuleConfig
        """
        return self._off_topic

    @off_topic.setter
    def off_topic(self, off_topic):
        """Sets the off_topic of this GenerativefirewallIndividualRulesConfig.


        :param off_topic: The off_topic of this GenerativefirewallIndividualRulesConfig.  # noqa: E501
        :type: GenerativefirewallOffTopicRuleConfig
        """

        self._off_topic = off_topic

    @property
    def denial_of_service(self):
        """Gets the denial_of_service of this GenerativefirewallIndividualRulesConfig.  # noqa: E501


        :return: The denial_of_service of this GenerativefirewallIndividualRulesConfig.  # noqa: E501
        :rtype: GenerativefirewallDenialOfServiceRuleConfig
        """
        return self._denial_of_service

    @denial_of_service.setter
    def denial_of_service(self, denial_of_service):
        """Sets the denial_of_service of this GenerativefirewallIndividualRulesConfig.


        :param denial_of_service: The denial_of_service of this GenerativefirewallIndividualRulesConfig.  # noqa: E501
        :type: GenerativefirewallDenialOfServiceRuleConfig
        """

        self._denial_of_service = denial_of_service

    @property
    def consistency_with_knowledgebase(self):
        """Gets the consistency_with_knowledgebase of this GenerativefirewallIndividualRulesConfig.  # noqa: E501


        :return: The consistency_with_knowledgebase of this GenerativefirewallIndividualRulesConfig.  # noqa: E501
        :rtype: GenerativefirewallConsistencyWithKnowledgebaseRuleConfig
        """
        return self._consistency_with_knowledgebase

    @consistency_with_knowledgebase.setter
    def consistency_with_knowledgebase(self, consistency_with_knowledgebase):
        """Sets the consistency_with_knowledgebase of this GenerativefirewallIndividualRulesConfig.


        :param consistency_with_knowledgebase: The consistency_with_knowledgebase of this GenerativefirewallIndividualRulesConfig.  # noqa: E501
        :type: GenerativefirewallConsistencyWithKnowledgebaseRuleConfig
        """

        self._consistency_with_knowledgebase = consistency_with_knowledgebase

    @property
    def indirect_prompt_injection(self):
        """Gets the indirect_prompt_injection of this GenerativefirewallIndividualRulesConfig.  # noqa: E501


        :return: The indirect_prompt_injection of this GenerativefirewallIndividualRulesConfig.  # noqa: E501
        :rtype: GenerativefirewallIndirectPromptInjectionRuleConfig
        """
        return self._indirect_prompt_injection

    @indirect_prompt_injection.setter
    def indirect_prompt_injection(self, indirect_prompt_injection):
        """Sets the indirect_prompt_injection of this GenerativefirewallIndividualRulesConfig.


        :param indirect_prompt_injection: The indirect_prompt_injection of this GenerativefirewallIndividualRulesConfig.  # noqa: E501
        :type: GenerativefirewallIndirectPromptInjectionRuleConfig
        """

        self._indirect_prompt_injection = indirect_prompt_injection

    @property
    def pii_detection_input(self):
        """Gets the pii_detection_input of this GenerativefirewallIndividualRulesConfig.  # noqa: E501


        :return: The pii_detection_input of this GenerativefirewallIndividualRulesConfig.  # noqa: E501
        :rtype: GenerativefirewallPiiDetectionRuleConfig
        """
        return self._pii_detection_input

    @pii_detection_input.setter
    def pii_detection_input(self, pii_detection_input):
        """Sets the pii_detection_input of this GenerativefirewallIndividualRulesConfig.


        :param pii_detection_input: The pii_detection_input of this GenerativefirewallIndividualRulesConfig.  # noqa: E501
        :type: GenerativefirewallPiiDetectionRuleConfig
        """

        self._pii_detection_input = pii_detection_input

    @property
    def pii_detection_output(self):
        """Gets the pii_detection_output of this GenerativefirewallIndividualRulesConfig.  # noqa: E501


        :return: The pii_detection_output of this GenerativefirewallIndividualRulesConfig.  # noqa: E501
        :rtype: GenerativefirewallPiiDetectionRuleConfig
        """
        return self._pii_detection_output

    @pii_detection_output.setter
    def pii_detection_output(self, pii_detection_output):
        """Sets the pii_detection_output of this GenerativefirewallIndividualRulesConfig.


        :param pii_detection_output: The pii_detection_output of this GenerativefirewallIndividualRulesConfig.  # noqa: E501
        :type: GenerativefirewallPiiDetectionRuleConfig
        """

        self._pii_detection_output = pii_detection_output

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GenerativefirewallIndividualRulesConfig, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GenerativefirewallIndividualRulesConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
